==> luna3-2.13.64-py3-none-any.whl: luna3/common/utils.py <==
"""
Common helpers
"""
import base64
import socket
from platform import platform
from typing import Any, Dict, List, Union

import aiohttp

from luna3.common.http_objs import RawDescriptor


def createBasicAuth(login: str, password: str) -> dict:
    """
    The function generates an authorization header for LUNA API (by login and password).

    Args:
        login: login
        password: password
    Returns:
        return dict *{'Authorization': 'Basic aG9ybnNhbmRob292ZXNAeWEucnU6c2VjcmV0cGFzc3dvcmQ=',
        'LUNA-Request-Id': 'RequestId'}*

    >>> createBasicAuth("hornsandhooves@ya.ru","secretpassword")
    {'Authorization': 'Basic aG9ybnNhbmRob292ZXNAeWEucnU6c2VjcmV0cGFzc3dvcmQ='}
    """
    strAuth = login + ":" + password
    base64Auth = base64.b64encode(str.encode(strAuth)).decode("utf-8")
    headers = {"Authorization": "Basic " + base64Auth}
    return headers


def checkPlatformCapability() -> bool:
    """
    Whether to use compiled bindings from `luna_core_queue_api`.

    Returns:
        True if the bindings are available
        False if the bindings are not available
    """
    return not any(
        (
            "debian" in platform().lower(),
            "ubuntu" in platform().lower(),
            "win" in platform().lower(),
            "linuxmint" in platform().lower(),
            "macos" in platform().lower(),
        )
    )


def encodeDescriptor(descriptor: bytes, encode: bool) -> Union[bytes, str]:
    """
    Encode descriptor to base64 bytes string if `encode` is True.

    Args:
        descriptor: raw descriptor
        encode: whether to encode descriptor or not

    Returns:
        encoded descriptor
    """
    return base64.b64encode(descriptor).decode("utf-8") if encode else descriptor


def getPreparedDescriptors(
    descriptors: List[Union[bytes, RawDescriptor]], encode: bool = True
) -> List[Union[str, Dict[str, Union[str, int]]]]:
    """
    Prepare descriptors to pass in json:
      - prepare binary descriptors as base64 strings,
      - prepare raw descriptors as dicts with 'descriptor' (as base64 string) and 'version' properties

    Args:
        descriptors: binary/raw descriptors to prepare
        encode: A flag, set to false to skip base64 encoding

    Returns:
        prepares descriptors
    """
    preparedDescriptors = []
    for descriptor in descriptors:
        if isinstance(descriptor, bytes):
            preparedDescriptors.append(encodeDescriptor(descriptor, encode))
        elif isinstance(descriptor, RawDescriptor):
            preparedDescriptors.append(
                {"version": descriptor.version, "descriptor": encodeDescriptor(descriptor.descriptor, encode)}
            )
        else:
            raise TypeError(f"unexpected descriptor type '{type(descriptor)}'")
    return preparedDescriptors


class DNSResolver(aiohttp.ThreadedResolver):
    """
    DNS resolver.
    """

    async def resolve(self, hostname: str, port: int = 0, family: int = socket.AF_INET) -> List[Dict[str, Any]]:
        """
        Resolve host by name

        Args:
            hostname: host name
            port: port
            family: family (https://docs.python.org/3/library/socket.html#socket-families)

        Returns:
            resolving hosts list
        """
        if family == socket.AF_UNSPEC:
            # problem with resolving localhost in dockers
            family = socket.AF_INET
        return await super().resolve(hostname=hostname, port=port, family=family)

==> luna3-2.14.65-py3-none-any.whl: luna3/common/utils.py <==
"""
Common helpers
"""

import base64
import socket
from platform import platform
from typing import Any, Dict, List, Union

import aiohttp

from luna3.common.http_objs import RawDescriptor


def createBasicAuth(login: str, password: str) -> dict:
    """
    The function generates an authorization header for LUNA API (by login and password).

    Args:
        login: login
        password: password
    Returns:
        return dict *{'Authorization': 'Basic aG9ybnNhbmRob292ZXNAeWEucnU6c2VjcmV0cGFzc3dvcmQ=',
        'LUNA-Request-Id': 'RequestId'}*

    >>> createBasicAuth("hornsandhooves@ya.ru","secretpassword")
    {'Authorization': 'Basic aG9ybnNhbmRob292ZXNAeWEucnU6c2VjcmV0cGFzc3dvcmQ='}
    """
    strAuth = login + ":" + password
    base64Auth = base64.b64encode(str.encode(strAuth)).decode("utf-8")
    headers = {"Authorization": "Basic " + base64Auth}
    return headers


def checkPlatformCapability() -> bool:
    """
    Whether to use compiled bindings from `luna_core_queue_api`.

    Returns:
        True if the bindings are available
        False if the bindings are not available
    """
    return not any(
        (
            "debian" in platform().lower(),
            "ubuntu" in platform().lower(),
            "win" in platform().lower(),
            "linuxmint" in platform().lower(),
            "macos" in platform().lower(),
        )
    )


def encodeDescriptor(descriptor: bytes, encode: bool) -> Union[bytes, str]:
    """
    Encode descriptor to base64 bytes string if `encode` is True.

    Args:
        descriptor: raw descriptor
        encode: whether to encode descriptor or not

    Returns:
        encoded descriptor
    """
    return base64.b64encode(descriptor).decode("utf-8") if encode else descriptor


def getPreparedDescriptors(
    descriptors: List[Union[bytes, RawDescriptor]], encode: bool = True
) -> List[Union[str, Dict[str, Union[str, int]]]]:
    """
    Prepare descriptors to pass in json:
      - prepare binary descriptors as base64 strings,
      - prepare raw descriptors as dicts with 'descriptor' (as base64 string) and 'version' properties

    Args:
        descriptors: binary/raw descriptors to prepare
        encode: A flag, set to false to skip base64 encoding

    Returns:
        prepares descriptors
    """
    preparedDescriptors = []
    for descriptor in descriptors:
        if isinstance(descriptor, bytes):
            preparedDescriptors.append(encodeDescriptor(descriptor, encode))
        elif isinstance(descriptor, RawDescriptor):
            preparedDescriptors.append(
                {"version": descriptor.version, "descriptor": encodeDescriptor(descriptor.descriptor, encode)}
            )
        else:
            raise TypeError(f"unexpected descriptor type '{type(descriptor)}'")
    return preparedDescriptors


class DNSResolver(aiohttp.ThreadedResolver):
    """
    DNS resolver.
    """

    async def resolve(self, host: str, port: int = 0, family: int = socket.AF_INET) -> List[Dict[str, Any]]:
        """
        Resolve host by name

        Args:
            host: host name
            port: port
            family: family (https://docs.python.org/3/library/socket.html#socket-families)

        Returns:
            resolving hosts list
        """
        if family == socket.AF_UNSPEC:
            # problem with resolving localhost in dockers
            family = socket.AF_INET
        return await super().resolve(host=host, port=port, family=family)
